package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.IntegralOrderLog;

/**
 * 积分订单日志Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IntegralOrderLogMapper 
{
    /**
     * 查询积分订单日志
     * 
     * @param id 积分订单日志主键
     * @return 积分订单日志
     */
    public IntegralOrderLog selectIntegralOrderLogById(Long id);

    /**
     * 查询积分订单日志列表
     * 
     * @param integralOrderLog 积分订单日志
     * @return 积分订单日志集合
     */
    public List<IntegralOrderLog> selectIntegralOrderLogList(IntegralOrderLog integralOrderLog);

    /**
     * 新增积分订单日志
     * 
     * @param integralOrderLog 积分订单日志
     * @return 结果
     */
    public int insertIntegralOrderLog(IntegralOrderLog integralOrderLog);

    /**
     * 修改积分订单日志
     * 
     * @param integralOrderLog 积分订单日志
     * @return 结果
     */
    public int updateIntegralOrderLog(IntegralOrderLog integralOrderLog);

    /**
     * 删除积分订单日志
     * 
     * @param id 积分订单日志主键
     * @return 结果
     */
    public int deleteIntegralOrderLogById(Long id);

    /**
     * 批量删除积分订单日志
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteIntegralOrderLogByIds(Long[] ids);
}
