package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.IntegralOrderLog;
import com.ruoyi.system.service.IIntegralOrderLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 积分订单日志Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/IntegralOrderLog")
public class IntegralOrderLogController extends BaseController
{
    @Autowired
    private IIntegralOrderLogService integralOrderLogService;

    /**
     * 查询积分订单日志列表
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralOrderLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(IntegralOrderLog integralOrderLog)
    {
        startPage();
        List<IntegralOrderLog> list = integralOrderLogService.selectIntegralOrderLogList(integralOrderLog);
        return getDataTable(list);
    }

    /**
     * 导出积分订单日志列表
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralOrderLog:export')")
    @Log(title = "积分订单日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, IntegralOrderLog integralOrderLog)
    {
        List<IntegralOrderLog> list = integralOrderLogService.selectIntegralOrderLogList(integralOrderLog);
        ExcelUtil<IntegralOrderLog> util = new ExcelUtil<IntegralOrderLog>(IntegralOrderLog.class);
        util.exportExcel(response, list, "积分订单日志数据");
    }

    /**
     * 获取积分订单日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralOrderLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(integralOrderLogService.selectIntegralOrderLogById(id));
    }

    /**
     * 新增积分订单日志
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralOrderLog:add')")
    @Log(title = "积分订单日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody IntegralOrderLog integralOrderLog)
    {
        return toAjax(integralOrderLogService.insertIntegralOrderLog(integralOrderLog));
    }

    /**
     * 修改积分订单日志
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralOrderLog:edit')")
    @Log(title = "积分订单日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody IntegralOrderLog integralOrderLog)
    {
        return toAjax(integralOrderLogService.updateIntegralOrderLog(integralOrderLog));
    }

    /**
     * 删除积分订单日志
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralOrderLog:remove')")
    @Log(title = "积分订单日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(integralOrderLogService.deleteIntegralOrderLogByIds(ids));
    }
}
